#
# spec file for package dbus-1-glib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname libdbus-glib-1-2

Name:           dbus-1-glib
Version:        0.112
Release:        3.5
Summary:        GLib-based library for using D-Bus
License:        AFL-2.1 OR GPL-2.0-or-later
URL:            https://dbus.freedesktop.org/
Source0:        https://dbus.freedesktop.org/releases/dbus-glib/dbus-glib-%{version}.tar.gz
Source1:        https://dbus.freedesktop.org/releases/dbus-glib/dbus-glib-%{version}.tar.gz.asc
Source2:        https://db.debian.org/fetchkey.cgi?fingerprint=DA98F25C0871C49A59EAFF2C4DE8FF2A63C7CC90#/%{name}.keyring
Source99:       baselibs.conf

BuildRequires:  libexpat-devel
BuildRequires:  libselinux-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1) >= 1.8
BuildRequires:  pkgconfig(gio-2.0) >= 2.40
BuildRequires:  pkgconfig(glib-2.0) >= 2.40
BuildRequires:  pkgconfig(gobject-2.0) >= 2.40

%description
D-Bus add-on library to integrate the standard D-Bus library with the
GLib thread abstraction and main loop.

%package -n %{soname}
Summary:        GLib-based library for using D-Bus
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
# Split provides: libdbus-glib-1.so.2 used to be in dbus-1-glib before 0.112
Provides:       %{name}:%{_libdir}/libdbus-glib-1.so.2

%description -n %{soname}
D-Bus add-on library to integrate the standard D-Bus library with the
GLib thread abstraction and main loop.

This package contains the shared library files.

%package -n dbus-1-glib-devel
Summary:        Developer package for D-Bus/GLib bindings
Requires:       %{soname} = %{version}
Requires:       dbus-1-glib-tool = %{version}

%description -n dbus-1-glib-devel
D-Bus add-on library to integrate the standard D-Bus library with the
GLib thread abstraction and main loop.

This package contains the devel and header files.

%package -n dbus-1-glib-doc
Summary:        Documentation for the D-Bus/GLib bindings
BuildArch:      noarch

%description -n dbus-1-glib-doc
D-Bus add-on library to integrate the standard D-Bus library with the
GLib thread abstraction and main loop.

This package contains developer documentation.

%package -n dbus-1-glib-tool
Summary:        Tool package for D-Bus/GLib bindings
Requires:       %{name} = %{version}

%description -n dbus-1-glib-tool
D-Bus add-on tool to integrate the standard D-Bus library with the
GLib thread abstraction and main loop.

This package contains dbus-binding-tool and manpage.

%package bash-completion
Summary:        Bash-completion package for D-Bus/GLib bindings
Requires:       dbus-1-glib-tool
Supplements:    (dbus-1-glib-tool and bash-completion)
# Up to version 0.112, the entire dbus-1-glib was in an unsplit package
Provides:       dbus-1-glib:/etc/bash_completion.d/dbus-bash-completion.sh
Conflicts:      dbus-1-glib < 0.112

%description bash-completion
D-Bus add-on tool to integrate the standard D-Bus library with the
GLib thread abstraction and main loop.

This package contains bash-completion support for %{name}.

%prep
%autosetup -p1 -n dbus-glib-%{version}

%build
%configure \
	--libexecdir=%{_libexecdir}/%{name}	\
%if 0%{?_crossbuild}
	--with-dbus-binding-tool=%{_bindir}/dbus-binding-tool \
%endif
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Remove the exacutable bit from dbus-bash-completion.sh
chmod -x %{buildroot}/%{_sysconfdir}/bash_completion.d/dbus-bash-completion.sh
# Create and move dbus-bash-completion.sh to the correct folder for openSUSE
mkdir %{buildroot}%{_datadir}/bash-completion/
mkdir %{buildroot}%{_datadir}/bash-completion/completions/
mv %{buildroot}/%{_sysconfdir}/bash_completion.d/dbus-bash-completion.sh \
  %{buildroot}%{_datadir}/bash-completion/completions/dbus-bash-completion.sh

%ldconfig_scriptlets -n %{soname}

%files -n %{soname}
%license COPYING
%doc NEWS
%{_libdir}/libdbus-glib-1.so.*

%files -n dbus-1-glib-devel
%{_includedir}/dbus-1.0/dbus/*
%{_libdir}/*glib*.so
%{_libdir}/pkgconfig/dbus-glib-1.pc

%files -n dbus-1-glib-doc
%doc CONTRIBUTING.md
%doc %{_datadir}/gtk-doc/html/dbus-glib

%files -n dbus-1-glib-tool
%{_bindir}/dbus-binding-tool
%{_mandir}/man?/dbus-binding-tool.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/dbus-bash-completion.sh
%{_libexecdir}/%{name}

%changelog
* Wed Nov  2 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Try to guard against incomplete update stacks (boo#1202241):
  + Add split-provides to libdbus-1-glib and bash-completion
    sub-package.
  + Add explicit conflict to bash-completion subpackage against
    dbus-1-glib < 0.112 (when the package split happened)
  + Ensure dbus-1-glib-tool gets the correct library version
    installed.
* Wed Dec  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add relevant dbus-1-glib-<targettype> provides/obsoletes also in
  baselibs.conf (boo#1193502).
* Wed Dec  1 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add signature and keyring as sources, verify tarball with gpg.
* Wed Nov 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.112:
  + Dependencies:
  - dbus 1.8 was already required, but is more strongly required
    now: the workarounds that were used to run continuous
    integration with dbus 1.6 on Ubuntu 14.04 'trusty' have been
    removed. (Note that dbus 1.8 has already reached end-of-life
    for security support, and newer dbus stable branches are
    strongly recommended.)
  - pkg-config 0.28 is required when building from git.
  + Enhancements:
  - Rewrite CONTRIBUTING.md document, based on Wayland's
    equivalent.
  - A generated ChangeLog file, which made up a significant
    proportion of the size of source tarball releases, is no
    longer included.
  - Improve man page.
  - Add test coverage for fdo#80557
  - Use more modern GLib assertions in unit tests.
  - Improve continuous integration to be run by GitLab in
    addition to Travis-CI.
  - Add clearer license information using
    SPDX-License-Identifier.
  + Fixes:
  - Allow glib-genmarshal to be overridden with
    `./configure GLIB_GENMARSHAL=/path/to/glib-genmarshal`, for
    cross-compilation.
  - Avoid a double-free in dbus-binding-tool for certain inputs,
    possibly involving nested introspection data structures.
  - Report a better error for excessive recursion depth or
    unsupported data types.
  - Map the 15 most-recently-added DBusGError members to their
    corresponding D-Bus error names.
  - Mark all documented symbols as deprecated.
  - Fix unit test failures during distcheck by enabling
    assertions.
  - Fix a core dump during installed-tests by not attempting to
    close a shared DBusConnection.
- Package COPYING as license, CONTRIBUTING.md and NEWS as docs.
- Add explicit pkgconfig BuildRequires.
- Replace dbus-1-devel and glib2-devel with pkgconfig variants that
  configure checks for: pkgconfig(dbus-1), pkgconfig(glib-2.0),
  pkgconfig(gobject-2.0) and pkgconfig(gio-2.0) BuildRequires.
- Drop hard Requires and BuildRequires that are not needed as they
  are added automatically.
- Split out bash-completion sub-package.
- Split out shared library into own sub-package, and Require it
  from the devel package, and add to the baselibs.conf. Following
  the SLPP standard. Add Provides and Obsoletes for the no longer
  existing main package.
- Use ldconfig_scriptlets for post(un) handling.
- Add soname define, ease future updates.
* Fri Jul 10 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 0.110:
  Dependencies:
  + GLib 2.40 is required
  Enhancements:
  + The GLib main-loop glue, "dbus-gmain", is now available as a separate
    subproject (the dbus-gmain branch in dbus-glib's git repository) for
    embedding in larger projects like dbus-glib and dbus-python via the
    `git subtree` or `git submodule` commands. This removes dbus-python's
    dependency on the rest of dbus-glib.
  Fixes:
  + autogen.sh can now detect gtk-doc >= 1.26.
  + More files have per-file copyright information.
- Run spec-cleaner
* Fri Jun  9 2017 meissner@suse.com
- remove CFLAGS setting, -fstack-protector is default and -fPIC
  will be auto-selected.
* Thu Oct 20 2016 zaitor@opensuse.org
- Split out dbus-binding-tool in own sub-package.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 0.108:
  + Use dbus-run-session instead of dbus-launch for tests.
- Changes from version 0.106:
  + Stop testing G_HAVE_INLINE, which ceased to work in GLib 2.47.2
    and wasn't meant to be API anyway. Instead, rely on "static
    inline" doing the right thing. On pre-C99 compilers, this
    relies on <glib.h> defining inline to __inline, __inline__ or
    the empty string if the compiler requires it, which it has done
    since 2000. (fdo#93513).
  + Stop calling g_mem_profile() in the tests, which no longer does
    anything and caused the tests to fail by issuing a warning.
  + Slightly modernize build system, and remove a weird
    cross-directory dependency which was breaking distcheck.
  + Stop distributing generated marshallers in the tarball.
- Run spec-clean, modernize spec-file macros and also drop a no
  longer conditional dbus-1-glib-64bit Obsoletes.
* Sat May 30 2015 zaitor@opensuse.org
- Update to version 0.104:
  + Deprecations: Document the entire library as deprecated.
  + Dependencies:
  - libdbus 1.8 is required.
  - GLib 2.32 is required.
  + Enhancements:
  - The libdbus 1.8 dependency means we can now document that
    dbus_g_thread_init() is idempotent and thread-safe
    (fdo#54770).
  - Use g_cclosure_marshal_generic for all marshalling
    (fdo#64214).
  + Fixes:
  - Allow timeouts to be migrated from one main context to
    another without an assertion failure (fdo#30574).
  - Don't trip a libdbus fatal warning if a Unix fd or other
    unsupported type is encountered in a message (fdo#80557).
  - Make the tests pass with newer GLib by not removing removed
    sources (fdo#83530).
  - Fix some typos in the documentation (fdo#45686).
  - Make the Autotools setup less awful (fdo#58698).
* Sun Feb 16 2014 zaitor@opensuse.org
- Update to version 0.102:
  + Enhancements:
  - Add dbus_g_method_invocation_get_connection (fdo#55729).
  - Add dbus_g_connection_open_private (fdo#55730).
  - Better regression tests (fdo#23633, fdo#40711, fdo#41129,
    fdo#51511, fdo#68603).
  - Get rid of more dead code (fdo#40711).
  - dbus-binding-tool: check validity of names (fdo#7909).
  + Bugs fixed:
  - dbus_g_value_build_g_variant: treat GValues containing
    (G_TYPE_STRING, NULL) or (G_TYPE_STRV, NULL) as empty string
    or empty array instead of asserting (fdo#71811).
  - Upload documentation correctly.
  - Fix under-linking (fdo#68601).
- Remove the exacutable bit from dbus-bash-completion.sh.
* Mon Mar 25 2013 zaitor@opensuse.org
- Update to version 0.100.2:
  + Respin tarball.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 0.100.1:
  + dbus-gproxy: Verify sender of NameOwnerChanged signals to be
    o.f.DBus (CVE-2013-0292, bnc#804392).
  + Some cleanups.
  + Other bugs fixed: fdo#23633, fdo#40711, fdo#55729, fdo#55730.
* Fri Sep 14 2012 vuntz@opensuse.org
- Update to version 0.100:
  + Enhancements:
  - Support building on Android with androgenizer
    (fdo#42532)
  - Respect NOCONFIGURE=1 in autogen.sh
  + Fixes:
  - Fix several GVariant reference leaks in
    dbus_g_value_parse_variant (fdo#41125)
  - Don't crash if an error code is out of range for its domain
    or has a negative code (fdo#40151)
  - Fix compilation with -Werror=format-security
  - Don't crash if dbus_g_proxy_new_for_peer() is used to talk to
    the dbus-daemon (fdo#41126)
* Thu Apr 19 2012 thoenig@suse.de
- Further dependency changes: Let dbus-1-glib-devel require
  dbus-1-devel (implicitly pulls dbus-1).
* Thu Apr 19 2012 thoenig@suse.de
- Fix and loosen dependency towards dbus-1. Reported by Andreas
  Jaeger <aj@suse.de>.
* Wed Jan 25 2012 cfarrell@suse.com
- license update: AFL-2.1 or GPL-2.0+
  License is a dual license choice of either Academic Free License 2.1 or
  GNU GPL 2+. This is the SPDX format for that license
* Wed Oct 12 2011 vuntz@opensuse.org
- Update to version 0.98:
  + Fix the documentation, a lot. We have nearly 100%% coverage now.
    (fdo#37793)
  + In specialized collection iterators, check that the type is
    correct; g_critical and return harmlessly, rather than
    crashing, if not
  + If library users register specialized GTypes, warn if their
    vtables have missing callbacks which would cause accessors to
    crash
  + Fix production of documentation out-of-tree with newer gtk-doc
  + Simplify invoke_object_method() and OOM handling in
    dbus-gobject (fdo#35767)
- Changes from version 0.96:
  + Fix a regression in marshalling GObject instances as object
    paths, which broke NetworkManager (fdo#37852, deb#628890)
  + Fix crashes when sending a message when disconnected from D-Bus
    but still working through our backlog of incoming messages,
    similar to fdo#12675 (fdo#38406)
  + Cope more gracefully, with a critical warning instead of a
    memory leak, if programmer error causes G_VALUE_COLLECT to fail
    (fdo#38406, nokia#86280, nokia#180486)
  + Avoid an assertion failure when unregistering a proxy if
    GetNameOwner failed (fdo#38408, nokia#116862)
  + Don't report various programmer errors as "out of memory";
    raise suitable critical warnings instead, and don't leak memory
    (fdo#35767, fdo#35766)
  + If a remote process sends a wrong method call on the Properties
    interface, send back an error reply, instead of warning on
    stderr and not replying (fdo#35766)
  + Show a warning if dbus_g_method_return fails to marshal
    something (fdo#29884, nokia#180486)
  + Remove remnants of i18n (fdo#36428)
  + Remove dead code (nokia#180486)
- Drop dbus-1-glib-fix-marshalling-regression.patch: fixed
  upstream.
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use host's dbus-binding-tool
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Add dbus-1-glib-devel to baselibs
* Thu Jul 21 2011 vuntz@opensuse.org
- Add dbus-1-glib-fix-marshalling-regression.patch: this fixes a
  regression causing issues in NetworkManager; taken from git.
* Fri Jun 17 2011 vuntz@opensuse.org
- Update to version 0.94:
  + Check validity of more arguments, don't report "out of memory"
    or "should not have been reached" if an invalid string or
    boolean is given, and abandon broken containers more gracefully
    (fdo#30171)
  + Allow underscores in error names (fdo#30274)
  + If an object is on more than one connection, emit signals on
    all of them; if it's unregistered, only unregister it from the
    requested connection (fdo#32087)
  + Fix ability to switch a DBusConnection from one GMainContext to
    another (fdo#35115)
  + Forbid a ReturnVal annotation after the first OUT <arg>, which
    had never worked correctly anyway (fdo#35952)
  + Remove false claim that we use Introspect() at runtime, and
    document more error cases (fdo#36216)
  + Remove unused support for translated messages (fdo#36428)
  + Don't corrupt internal data if a GObject is registered twice on
    the same (connection, path) tuple, and fix out-of-bounds
    reading (fdo#36793)
  + Fix multiple signal emissions if an object is removed from all
    of its locations then re-exported, and a memory leak if an
    exported object is disposed (fdo#36811)
  + Log the error message if object registration fails (fdo#37795)
  + Several small fixes.
  + Remove Doxygen support (as gtk-doc is used) (fdo#10890)
  + Build fixes.
  + Bugs fixed: fdo#22667, fdo#22854, fdo#23616, fdo#26952,
    fdo#27193, fdo#27598, fdo#29884, fdo#32351, fdo#33145,
    fdo#33646, fdo#34282, fdo#37060, fdo#37062, fdo#37789,
    fdo#37790, fdo#37812.
* Mon Dec 20 2010 vuntz@opensuse.org
- Update to version 0.92:
  + Require glib 2.26: this dependency bump was missed in 0.90.
* Wed Nov 10 2010 vuntz@opensuse.org
- Update to version 0.90:
  + Add DBusGObjectPath, DBusGSignature typedefs
  + Give specialized GArrays iteration/appending support
  + fdo#30428: add dbus_g_value_parse_g_variant
  + Fix switching a connection's GMainContext
  + Various small fixes
* Thu Aug 26 2010 vuntz@opensuse.org
- Update to version 0.88:
  + Allow duplicate object path registrations for different
    connections
  + Don't use the identifier "interface" in public headers
  + Don't pass malformed error interface to dbus (rh#581794)
  + Fix a crash in dbus_pending_call_cancel() (fdo#14579)
  + Fix lookup of regular properties when shadow properties are
    used
  + fdo#28715: Add dbus_g_value_build_g_variant()
  + Support DBUS_TYPE_G_SIGNATURE
  + Respect property access flags for writing, allow disabling for
    reads
  + Documentation improvements
  + Build fixes, especially for windows
- Drop bug-628607-access-flags-CVE-2010-1172.diff: fixed upstream.
* Fri Aug 13 2010 lnussel@suse.de
- honor access properties from xml file (CVE-2010-1172, bnc#628607)
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Thu Mar 25 2010 vuntz@opensuse.org
- Update to version 0.86:
  + core: allow duplicate property names on GInterfaces
  + core: performance optimization for object info lookup
  + Fix hyphenated error codes correctly
  + Free errors returned by method implementations
  + Trivial compiler warning fixes
  + Use AM_SILENT_RULES if available
  + Turn the gtk-doc documentation into buildable shape
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 0.84:
  + Support duplicate object registrations
  + Only re-set registration list if it's non-empty
  + Copy object registration list when unregistering.
  + fdo#19623 - Add dbus_g_bus_get_private
  + fdo#25119 - Don't leak DBusGMethodInvocation for no-reply calls
  + Import dbus-bus-introspect.xml upstream
  + dbus-gvalue: set an error when demarshal_basic doesn't
    recognize type
  + Man page fixes.
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
- package documentation as noarch
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 0.82:
  + Fix format-security warning
  + Use -fno-strict-aliasing by default
  + fdo#14183 - Listen to NameOwnerChanged using arg0 matching
  + Use g_strdup instead of strdup in dbus_g_method_get_sender
  + fdo#13908: make dbus_g_type_specialized_init() safe for library
    users to call
  + fdo#16776: teach dbus_g_method_return_error about DBUS_GERROR
  + fdo#20884: dbus_g_proxy_manager_replace_name_owner: don't leave
    freed memory in the hash table if the name was the owner's
    first
  + dbus_g_type_specialized_init: make some effort at being
    thread-safe
  + add --with-dbus-binding-tool configure option to use an
    external dbus-binding-tool
  + fdo#5688: don't assert when exported object is destroyed
  * after* D-Bus connection closes
  + fdo#21219: implement unregistration of objects
  + dbus-gobject: save the ObjectRegistration on each object, not
    just the path
  + fdo#20879 - Use --skip-source argument for glib-genmarshal
  + fdo#19927 - Use const for GError * param we're not modifying
  + fdo#13908: silently initialize specialized types whenever
    required
  + fdo#21362 - Remove use of deprecated symbols
  + fdo#21753 - Correctly initialize GValues in dbus-binding-tool
    generated code
  + fdo#22244 - Only include <glib.h>, not individual headers
  + fdo#20343 - Add a man page for dbus-binding-tool
  + fdo#18294 - Be defensive about a possibly NULL property string
  + Various build fixes.
- Remove AutoReqProv: it's default now.
- Remove -fno-strict-aliasing from our custom CFLAGS since it's by
  default now.
- Drop dbus-1-glib-selinux.patch: unneeded now.
- Drop marshall-skip-source.patch: fixed upstream.
- Use libexecdir whenever possible.
- Remove Requires from doc package since it's purely html files.
* Mon Jul 20 2009 aj@suse.de
- Do not add source file name as comment for glib-genmarshall Aufruf.
  This creates otherwise files with temporary filenames that make
  comparison of builds impossible (marshall-skip-source.patch)
* Tue Feb  3 2009 thoenig@suse.de
- Update to version 0.80
  - handle nested nodes in dbus-binding-tool
  - Always use /etc/bash_completion.d
  - Move test-types inside run-test to avoid dep on existing session
  bus
  - Don't send replies for messages explicitly not requesting one
* Sat Jan 24 2009 vuntz@novell.com
- Use %%{_prefix}/lib/%%{name} for libexecdir
- Fix a few rpmlint warnings:
  + Recompress tarball as bz2
  + Move /usr/lib/libdbus-glib-1.so to devel package
  + Disable static libraries
* Thu Jan  1 2009 mboman@suse.de
- Update to version 0.78
  + add bash completion for dbus-send(1)
  + fdo#17329: allow hash tables to contain complex types
  + fdo#17798: add support for 'o', 'g' and 'as' in dictionaries
  + fdo#17797: add support for 'g' type, as a boxed char *
  + fdo#17795: depend on Glib 2.10 for hash unref consistency
  + fdo#17794: make run-test.sh fail when die is called
  + fdo#18573 - Fix race when service appears and disappears quickly
  + fdo#17614: Use g_slice for allocating temporary async call data
  + fdo#10373: Use of deprecated API (was used incorrectly)
  + fdo#16419: stack overflow demarshaling recursive variants
  + fdo#16114 [patch] wincaps-to-uscore property names for GetAll()
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Aug 25 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Wed Jun 25 2008 aj@suse.de
- Do not require gtk-doc to build.
* Tue Jun 17 2008 thoenig@suse.de
- Update to dbus-1-glib 0.76
- Critical fixes:
  - ABI now guaranteed frozen
  - Fix broken introspection XML
  - Return an error on unknown property Get
  - Fix error handling in dbus_g_proxy_end_call_internal
- Other notable fixes:
  - Fixes for /bin/sh as dash
  - Fixes for non-gcc compilers
  - Correctly detect path to dbus-daemon
  - : Memory leak fixes
  - New function to specify default timeout for calls on proxy
  - Implement org.freedesktop.DBus.Properties.GetAll
  - Require DBus 1.1
- Drop patches which went upstream
* Tue May 13 2008 aj@suse.de
- Reduce BuildRequires.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Feb 29 2008 tambet@suse.de
- Fix the generated introspection XML (patch from upstream).
- Fix the bug where GObject signals get emitted twice per dbus signal
  (bfo #12505).
- Make the dbus-binding-tool ignore XML namespaces it doesn't understand,
  making it possible to add documentation to the same place where interface
  definitions live (bfo #14429).
* Wed Jun 27 2007 thoenig@suse.de
- Update to dbus-1-glib 0.74
- Changes:
  * Init threading first to stop a warning from new GLib.
  * Remove the XML documentation support in configure
  * Fix typo in _dbus_gvalue_signals_error
  * Update GLib requirement.
  * Document dbus-gtype-specialized
  * Add simple test suite for peer objects.
  * Support peer-to-peer proxies.
  * Add dbus_connection_get_g_connection.
  * Stop compiler warnings.
  * Handle dbus errors which are not name has no owner
  * Update abstract socket test from DBus, which now cross-compiles
  * Rename the error quark to be unique
  * Update AUTHORS
* Sat Apr 28 2007 aj@suse.de
- Add libexpat-devel to build requires.
* Thu Mar  1 2007 thoenig@suse.de
- new upstream version 0.73
- new package dbus-1-glib-doc
- drop patch dbus-glib-introspect-fix-thoenig-01.patch
* Mon Nov  6 2006 thoenig@suse.de
- loosen dependency to D-Bus
* Tue Aug  1 2006 thoenig@suse.de
- new upstream version 0.71
- new package: dbus-1-glib-devel
- moved dbus-binding-tool from dbus-1-glib to dbus-1-glib-devel
- moved GLib header and .la files from dbus-1-devel to
  dbus-1-glib-devel
* Tue Aug  1 2006 thoenig@suse.de
- split out binings to sparate spec files
